@@ -149,6 +149,7 @@ public abstract class Supervisor extends HttpServlet {
 		if ( holder.search_engine )	return URIAttribute.encode( uri, enc );
 		String[]	part = uri.split( "/" );
 		boolean	flag = false;
+		String	head = null;
 		for ( int i = 0; i < part.length; i++ ) {
 			int	def_no;
 			for ( def_no = 0; def_no < LINK_DEF.length; def_no++ ) {
@@ -165,18 +166,26 @@ public abstract class Supervisor extends HttpServlet {
 			case 1:
 			case 2:
 				part[i] = resolveHost( holder, part[i], def_no );
+				part[i] = "";
 				break;
 			}
 		}
 		if ( flag ) {
 			StringBuffer	buf = new StringBuffer( part[0] );
 			for ( int i = 1; i < part.length; i++ ) {
-				buf = buf.append( "/" );
+				if ( buf.length() > 0 )	buf = buf.append( "/" );
 				buf = buf.append( part[i] );
 			}
 			uri = buf.toString();
 		}
-		return holder.response.encodeURL( URIAttribute.encode( uri, enc ) );
+		uri = holder.response.encodeURL( URIAttribute.encode( uri, enc ) );
+		if ( head != null ) {
+			StringBuilder	buf = new StringBuilder( head );
+			buf = buf.append( "/" );
+			buf = buf.append( uri );
+			uri = buf.toString();
+		}
+		return uri;
 	}
 
 	/**
